@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::GitLab::Create 1.0001;
+package Dist::Zilla::Plugin::GitLab::Create 1.0002;
 
 use Modern::Perl;
 use JSON::MaybeXS;
@@ -132,7 +132,7 @@ sub after_mint {
    $params->{merge_requests_enabled} = $self->merge_requests;
    $self->log(
       [
-         'Snippets are %s',
+         'Merge requests are %s',
          $params->{merge_requests_enabled} ? 'enabled' : 'disabled'
       ]
    );
@@ -161,7 +161,7 @@ sub after_mint {
       my $git = Git::Wrapper->new($root);
 
       $self->log( [ 'Setting GitLab remote \'%s\'', $self->remote ] );
-      $git->remote( 'add', $self->remote, $repo->{ssh_url} );
+      $git->remote( 'add', $self->remote, $repo->{ssh_url_to_repo} );
 
       my ($branch) = try {
          $git->rev_parse( { abbrev_ref => 1, symbolic_full_name => 1 },
@@ -207,7 +207,7 @@ Dist::Zilla::Plugin::GitLab::Create - Create a new GitLab repo on dzil new
 
 =head1 VERSION
 
-version 1.0001
+version 1.0002
 
 =head1 SYNOPSIS
 
