@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::GitLab 1.0001;
+package Dist::Zilla::PluginBundle::GitLab 1.0002;
 
 use Modern::Perl;
 use Carp;
@@ -115,7 +115,7 @@ Dist::Zilla::PluginBundle::GitLab - Access GitLab functionality to maintain dist
 
 =head1 VERSION
 
-version 1.0001
+version 1.0002
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ then, in your F<dist.ini>:
 
 This bundle automatically adds the plugins
 L<GitLab::Meta|Dist::Zilla::Plugin::GitLab::Meta>
-and L<[GitLab::Update|Dist::Zilla::Plugin::GitLab::Update>.
+and L<GitLab::Update|Dist::Zilla::Plugin::GitLab::Update>.
 
 =head1 ATTRIBUTES
 
